prijsoog.supermarkets package
=============================

Submodules
----------

prijsoog.supermarkets.ah module
-------------------------------

.. automodule:: prijsoog.supermarkets.ah
    :members:
    :undoc-members:
    :show-inheritance:

prijsoog.supermarkets.jumbo module
----------------------------------

.. automodule:: prijsoog.supermarkets.jumbo
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: prijsoog.supermarkets
    :members:
    :undoc-members:
    :show-inheritance:
